package com.ti.mobpo.ui

import androidx.compose.animation.EnterTransition
import androidx.compose.animation.ExitTransition
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Favorite
import androidx.compose.material.icons.filled.Home
import androidx.compose.material.icons.filled.Person
import androidx.compose.material.icons.outlined.FavoriteBorder
import androidx.compose.material.icons.outlined.Home
import androidx.compose.material.icons.outlined.Person
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.NavigationBar
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.rememberUpdatedState
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import com.ti.mobpo.ui.screens.Favourites
import com.ti.mobpo.ui.screens.PokeSearchScreen

@Composable
fun Navigation() {
    val items = listOf(
        BottomNavigationItem(
            title = "Home",
            selectedIcon = Icons.Filled.Home,
            unselectedItem = Icons.Outlined.Home,
            route = Screen.PokeSearch.route
        ),
        BottomNavigationItem(
            title = "Favourites",
            selectedIcon = Icons.Filled.Favorite,
            unselectedItem = Icons.Outlined.FavoriteBorder,
            route = Screen.Favourites.route
        )
    )

    var selectedItemIndex by rememberSaveable {
        mutableStateOf(0)
    }
    val navController = rememberNavController()

    val currentBackStackEntry by navController.currentBackStackEntryAsState()
    val currentRoute = currentBackStackEntry?.destination?.route
    val updatedSelectedIndex = items.indexOfFirst { it.route == currentRoute }
    selectedItemIndex = rememberUpdatedState(updatedSelectedIndex).value

    val pokeSearchViewModel: PokeSearchViewModel = viewModel()

    Scaffold (
        bottomBar = {
            NavigationBar {
                items.forEachIndexed { index, item ->
                    NavigationBarItem(
                        selected = selectedItemIndex == index,
                        onClick = {
                            selectedItemIndex = index
                            println("Navigating to ${item.route}")
                            navController.navigate(item.route)
                        },
                        label = { Text(item.title) },
                        alwaysShowLabel = true,
                        icon = {
                            Box {
                                Icon(imageVector = if (index == selectedItemIndex) {
                                    item.selectedIcon
                                } else {
                                    item.unselectedItem
                                }, contentDescription = item.title)
                            }
                        }
                    )
                }
            }
        },
        content = { innerPadding ->
            Surface(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(innerPadding),
                color = MaterialTheme.colorScheme.background,
                content = {
                    NavHost(
                        navController = navController,
                        startDestination = Screen.PokeSearch.route,
                        enterTransition = {
                            EnterTransition.None
                        },
                        exitTransition = {
                            ExitTransition.None
                        }) {
                        composable(route = Screen.PokeSearch.route) {
                            PokeSearchScreen(pokeSearchViewModel)
                        }
                        composable(
                            route = Screen.Favourites.route) {
                            Favourites()
                        }
                    }
                }
            )
        }
    )
}


@Preview(showBackground = true)
@Composable
fun NavigationPreview() {
    Surface {
        val pokeSearchViewModel: PokeSearchViewModel = viewModel()
        PokeSearchScreen(pokeSearchViewModel)
    }
}